@@ -56,7 +56,16 @@ class Github:
                           "Accept-Encoding": "gzip, deflate, br",
                           "Referer": "https://github.com",
                           "Connection": "keep-alive",
-                          "Cookie": "user_session=kwO7LcPSqCVUguEf7xonR6ycKmuqm8XvI0qVco0FjE1ZKY1w;"}
+                          "Cookie": "_octo=GH1.1.1146312575.1623244599; logged_in=yes; "
+                                    "_device_id=ac7f336e5550e9066acc023e06b2c585; "
+                                    "user_session=B83-_SQf7PNRM8t5OMOEcx05bA7eqDiGnDPN58JYATBytS2w; "
+                                    "__Host-user_session_same_site=B83-_SQf7PNRM8t5OMOEcx05bA7eqDiGnDPN58JYATBytS2w; "
+                                    "dotcom_user=elkorsananwar; has_recent_activity=1; "
+                                    "color_mode=%7B%22color_mode%22%3A%22auto%22%2C%22light_theme%22%3A%7B%22name%22%3A%22light"
+                                    "%22%2C%22color_mode%22%3A%22light%22%7D%2C%22dark_theme%22%3A%7B%22name%22%3A%22dark%22%2C"
+                                    "%22color_mode%22%3A%22dark%22%7D%7D; tz=Africa%2FCairo"
+
+                          }
 
         try:
             countryName = str(self.__resp["location"]).split(",")[1].strip()
@@ -427,7 +436,7 @@ class Github:
             user = self.username
         soup = _BeautifulSoup(_get(f"https://github.com/{user}", headers=self.__headers).text, "html.parser")
         try:
-            userEmail = soup.find('a', {"class": "u-email Link--primary"}).text
+            userEmail = soup.find('a', attrs={"class": "u-email Link--primary"}).text
         except AttributeError:  # email is NOT provided.
             userEmail = None
 
